#
# spec file for package goss
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define dgoss_name dgoss
%define kgoss_name kgoss
%define dcgoss_name dcgoss

Name:           goss
Version:        0.4.2
Release:        1.4
Summary:        Quick and Easy server testing/validation
License:        Apache-2.0
Group:          Development/Tools/Other
URL:            https://github.com/aelsabbahy/goss
Source0:        https://github.com/goss-org/goss/archive/refs/tags/v%{version}.tar.gz#/goss-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.18

%description
Goss is a YAML based serverspec alternative tool for validating a server’s configuration. It eases the process of writing tests by allowing the user to generate tests from the current system state. Once the test suite is written they can be executed, waited-on, or served as a health endpoint.

%prep
%setup -q
tar -zxf %{SOURCE1}

%build
GO111MODULE=on CGO_ENABLED=0 go build -mod=vendor -o %{name} -buildmode=pie \
	-ldflags "-s -w -X main.version=%{version}" ./cmd/goss/goss.go

%install
install -D -m0755 %{name} %{buildroot}%{_bindir}/%{name}
install -D -m0755 extras/%{dgoss_name}/%{dgoss_name} %{buildroot}%{_bindir}/%{dgoss_name}
install -D -m0755 extras/%{kgoss_name}/%{kgoss_name} %{buildroot}%{_bindir}/%{kgoss_name}
install -D -m0755 extras/%{dcgoss_name}/%{dcgoss_name} %{buildroot}%{_bindir}/%{dcgoss_name}

%files
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{dgoss_name}
%{_bindir}/%{kgoss_name}
%{_bindir}/%{dcgoss_name}

%changelog
* Tue Oct 10 2023 Jochen Breuer <brejoc@gmail.com> - 0.4.2
- Update to version 0.4.2 with updated dependencies in vendor file
  * Please check out v4 migration guide:
    https://github.com/goss-org/goss/blob/master/docs/v4_migration.md
  * Added ctx object to all system struct's constructors by @aelsabbahy in gh#837
  * Changed: Reworded syntax error messages to be clearer by @aelsabbahy in gh#838
  * Fix json by @aelsabbahy in gh#841
  * Command empty strings by @aelsabbahy in gh#839
  * Added: goss-darwin-arm64 binary to release by @aelsabbahy in gh#835
  * Goss v0.4.X introduces some major enhancements to the matching logic allowing far more flexibility for asserts.
  * For example, can assert that the output of echo "3" is less than 5.
  * Added: transforms support (closes gh#538)
  * Allows comparison of string to int, ex: ensuring a systctl output below/above a specific number (closes gh#220)
  * Allows JSON parsing/validation support (closes gh#578)
  * Allows comparing command output to a string, this will display the failed output on failure (closes gh#483)
  * -o include_raw will show the non-transformed value
  * Added: Some new matchers
  * equal matcher added to do strict type comparison (e.x. string to string)
  * contain-substring
  * have-patterns - This mimics the existing default behavior of file contents and command output
  * contain-elements - checks that an array value matches a set of matchers
  * Added: runlevels support for service
  * Added: option to sort output (closes gh#416)
  * Added: All resources now support key override (closes gh#518, closes gh#742)
  * Added: Use exit code 78 if test file is unparseable (closes gh#317)
  * Changed: removed alpha from non-linux binary names
  * Changed: StartTime is no longer calculated from goss start. Calculated from first test start, this allows accurate reporting when showing a cached result
  * Changed: Completely re-worked matchers and shared output logic
  * Changed: Cache test results in serve instead of output (closes gh#612)
  * Added: Significantly improved test coverage of matcher, output code
  * Changed: Doc to reference cat -E /proc/<PID>/comm to avoid whitespace issues (closes gh#762)
  * Changed: Removed file.Size from autoadd (closes gh#262)
  * Added: matcher.as-reader this allows the matcher string to behave as an io.Reader output. Can be useful for testing
  * Removed: json_online output format, use: goss v -f json -o oneline
  * Added: windows and darwin alpha binaries back in the release (gh#829)
  * Added: string diff support (gh#827)
  * Added: mount vfs-opts support (gh#826)
* Tue Jun 27 2023 Andrea Manzini <andrea.manzini@suse.com> - 0.3.23
- Update to version 0.3.23 with updated dependencies in vendor file
  * Add: log level to be set (gh#802)
  * kgoss: add new GOSS_KUBECTL_OPTS env var to inject more options (gh#792)
  * Fix: Error message encoding when output is set to JSON (gh#788)
  * Add: Implement prometheus output support (gh#607)
  * Add: Add optional TLS client cert authentication + custom ca-file (gh#686)
  * Fix: json typo in http resource (gh#673)
  * Fix: kgoss Remove --generator as it has been deprecated (gh#768)
  * Fix: kgoss Fixed kgoss kubectl cp issue (gh#773)
* Sat Sep 10 2022 Jochen Breuer <brejoc@gmail.com> - 0.3.18
- Update to version 0.3.18 with updated dependencies in vendor file
  * Update all dependencies to latest versions
  * dgoss - Add support for podman as the container backend (gh#748)
* Tue Dec 15 2020 Jochen Breuer <jbreuer@suse.de>
- Scripts for dgoss, kgoss and dcgoss are now also included.
* Thu Dec 10 2020 Jochen Breuer <jbreuer@suse.de>
- Initial commit for goss version 0.3.15
